@@ -18,7 +18,6 @@ extern crate reverse_geocoder;
 extern crate serde;
 extern crate serde_json;
 extern crate tabwriter;
-//extern crate textwrap;
 extern crate threadpool;
 extern crate uuid;
 
@@ -185,6 +184,7 @@ enum Command {
     FixLengths,
     Flatten,
     Fmt,
+    ForEach,
     Frequency,
     Headers,
     Help,
@@ -208,8 +208,6 @@ enum Command {
     Stats,
     Table,
     Transpose,
-    #[cfg(target_family = "unix")]
-    ForEach,
 }
 
 impl Command {
@@ -263,7 +261,6 @@ impl Command {
             Command::Stats => cmd::stats::run(argv),
             Command::Table => cmd::table::run(argv),
             Command::Transpose => cmd::transpose::run(argv),
-            #[cfg(target_family = "unix")]
             Command::ForEach => cmd::foreach::run(argv),
         }
     }
